==> custom_pages-v1.12.8.zip: custom_pages/messages/de/view.php <==
<?php
return [
  '<strong>Copy</strong> Custom Page' => '',
  '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong>Info: </strong> Mit "Nur Admin" gekennzeichnete Seiten werden im Stream nicht angezeigt!',
  'Add new {pageType}' => 'Neuen {pageType} hinzufügen',
  'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'Indem du einen URL-Verknüpfungswert setzt, kannst du eine besser lesbare URL für deine Seite erstellen. Wenn <b>URL Rewriting</b> auf Deiner Seite aktiviert ist, wird der Wert \'mypage\' zu einer URL \'www.example.de/p/mypage\' führen.',
  'Configuration' => 'Konfiguration',
  'Copy' => '',
  'Create' => 'Erstellen',
  'Create new template' => 'Neue Vorlage erstellen',
  'Delete' => 'Löschen',
  'Edit template' => 'Vorlage bearbeiten',
  'Empty' => 'Leer',
  'Exit Edit Mode' => '',
  'Here you can configure the general settings of your {pageLabel}.' => 'Hier kannst du die allgemeinen Einstellungen von {pageLabel} definieren.',
  'Inline Editor' => 'Inline-Editor',
  'Multiple' => 'Mehrere',
  'Open page...' => 'Seite öffnen ...',
  'Page configuration' => 'Seiten Konfiguration',
  'Save' => 'Speichern',
  'Settings' => 'Einstellungen',
  'The abstract will be used as stream entry content to promote the actual page. 
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => 'Die Beschreibung wird im zur Seite gehörenden Eintrag des Streams angezeigt. Wenn keine Beschreibung angegeben wird oder die Seite nur für Administratoren sichtbar ist, wird kein Eintrag im Stream vorgenommen.',
  'This page lists all available custom content entries.' => 'Diese Seite führt alle verfügbaren Drittinhalte auf.',
  'This section has no editable elements.' => '',
  'View not found' => 'View nicht gefunden',
  'You don\'t have permission to access the page' => '',
  'You need to be a system administrator to edit this URL' => 'Nur Systemadministratoren können diese URL bearbeiten',
  'e.g. allowfullscreen allow="camera; microphone"' => 'z.B. allowfullscreen allow="camera; microphone"',
  'e.g. http://www.example.de' => 'z.B. http://www.beispiel.de',
  'none' => 'keine',
];

==> custom_pages-v1.12.12.zip: custom_pages/messages/de/view.php <==
<?php
return [
  '<strong>Copy</strong> Custom Page' => '<strong>Benutzerdefinierte Seite kopieren</strong>',
  '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong>Info: </strong> Mit "Nur Admin" gekennzeichnete Seiten werden im Stream nicht angezeigt!',
  'Add new {pageType}' => 'Neuen {pageType} hinzufügen',
  'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'Indem du einen URL-Verknüpfungswert setzt, kannst du eine besser lesbare URL für deine Seite erstellen. Wenn <b>URL Rewriting</b> auf Deiner Seite aktiviert ist, wird der Wert \'mypage\' zu einer URL \'www.example.de/p/mypage\' führen.',
  'Configuration' => 'Konfiguration',
  'Copy' => 'Kopieren',
  'Create' => 'Erstellen',
  'Create new template' => 'Neue Vorlage erstellen',
  'Delete' => 'Löschen',
  'Edit template' => 'Vorlage bearbeiten',
  'Empty' => 'Leer',
  'Exit Edit Mode' => 'Bearbeitungsmodus verlassen',
  'Here you can configure the general settings of your {pageLabel}.' => 'Hier kannst du die allgemeinen Einstellungen von {pageLabel} definieren.',
  'Inline Editor' => 'Inline-Editor',
  'Multiple' => 'Mehrere',
  'Open page...' => 'Seite öffnen ...',
  'Page configuration' => 'Seiten Konfiguration',
  'Save' => 'Speichern',
  'Settings' => 'Einstellungen',
  'The abstract will be used as stream entry content to promote the actual page. 
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => 'Die Beschreibung wird im zur Seite gehörenden Eintrag des Streams angezeigt. Wenn keine Beschreibung angegeben wird oder die Seite nur für Administratoren sichtbar ist, wird kein Eintrag im Stream vorgenommen.',
  'This page lists all available custom content entries.' => 'Diese Seite führt alle verfügbaren Drittinhalte auf.',
  'This section has no editable elements.' => 'Dieser Abschnitt enthält keine bearbeitbaren Elemente.',
  'View not found' => 'View nicht gefunden',
  'You don\'t have permission to access the page' => 'Du hast keine Berechtigung, auf die Seite zuzugreifen.',
  'You need to be a system administrator to edit this URL' => 'Nur Systemadministratoren können diese URL bearbeiten',
  'e.g. allowfullscreen allow="camera; microphone"' => 'z.B. allowfullscreen allow="camera; microphone"',
  'e.g. http://www.example.de' => 'z.B. http://www.beispiel.de',
  'none' => 'keine',
];
